==> paraview-5.12.1-8-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/StereoCursorView-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;VTK::CommonCore")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::InteractionWidgets;VTK::RenderingCore")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_library_name" "StereoCursorViews")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPVStereoCursorView.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/StereoCursorViewsModule.h")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/StereoCursorView/vtk/hierarchy/StereoCursorView/StereoCursorViews-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/StereoCursorView-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;VTK::CommonCore")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::InteractionWidgets;VTK::RenderingCore")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_library_name" "StereoCursorViews")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPVStereoCursorView.h")
set_property(TARGET "StereoCursorView::StereoCursorViews" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/StereoCursorView/vtk/hierarchy/StereoCursorView/StereoCursorViews-hierarchy.txt")
unset(_vtk_module_import_prefix)
